==> getml-0.16.0-py3-none-any.whl: getml/feature_learning/__init__.py <==
# Copyright 2021 The SQLNet Company GmbH

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

"""This module contains relational learning algorithms to learn features
from relational data or time series.

Note:

    All feature learners need to be passed to :class:`~getml.pipeline.Pipeline`.


"""

from . import aggregations, loss_functions
from .fastprop_model import FastPropModel
from .fastprop_time_series import FastPropTimeSeries
from .feature_learner import _FeatureLearner
from .multirel_model import MultirelModel
from .multirel_time_series import MultirelTimeSeries
from .relboost_model import RelboostModel
from .relboost_time_series import RelboostTimeSeries
from .relmt_model import RelMTModel
from .relmt_time_series import RelMTTimeSeries

__all__ = (
    "FastPropModel",
    "FastPropTimeSeries",
    "MultirelModel",
    "MultirelTimeSeries",
    "RelboostModel",
    "RelMTModel",
    "RelMTTimeSeries",
    "RelboostTimeSeries",
    "aggregations",
)

==> getml-1.0.0-py3-none-any.whl: getml/feature_learning/__init__.py <==
# Copyright 2021 The SQLNet Company GmbH

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

"""This module contains relational learning algorithms to learn features
from relational data or time series.

Note:

    All feature learners need to be passed to :class:`~getml.Pipeline`.


"""

from . import aggregations, loss_functions
from .fastprop import FastProp
from .feature_learner import _FeatureLearner
from .multirel import Multirel
from .relboost import Relboost
from .relmt import RelMT

__all__ = (
    "_FeatureLearner",
    "FastProp",
    "Multirel",
    "Relboost",
    "RelMT",
    "aggregations",
    "loss_functions",
)
